# ExperiBot
## Telegram bot to keep track of ML experiments

Installation: 
- pip install experibot

Bot usage: 
- /raw_scalars Show the last iteration of selected scalars
- /draw_scalars Draw the selected scalars

Currently only can track one experiment. See example.py

You should set the enviroment variable TELE_BOT to the token provided by Telegram.